#ifndef HARDWARE_H
#define HARDWARE_H

#include <io.h>
#include <signal.h>
#include <iomacros.h>


//PINS

//PORT1 = Rotary key
#define LED_YELLOW      BIT0
#define ROTKEY_A        BIT5
#define ROTKEY_B        BIT6
#define ROTKEY_BTN      BIT7

//PORT5 = LCD
#define LCD_RS          BIT6
#define LCD_RW          BIT5
#define LCD_E           BIT4
#define LCD_D4          BIT0
#define LCD_D5          BIT1
#define LCD_D6          BIT2
#define LCD_D7          BIT3

//for the lcd.c module
#define LCDOUT          P5OUT
#define LCDDIR          P5DIR
#define LCDIN           P5IN


//Port Output Register 'P1OUT, P5OUT':
#define P1OUT_INIT      0                       // Init Output data of port1
#define P5OUT_INIT      0                       // Init Output data of port2

//Port Direction Register 'P1DIR, P5DIR':
#define P1DIR_INIT      0x1f                    // Init of Port1 Data-Direction Reg (Out=1 / Inp=0)
                                                // P1.5-P1.7 = input (rotary key)
#define P5DIR_INIT      0xff                    // Init of Port2 Data-Direction Reg (Out=1 / Inp=0)

//Selection of Port or Module -Function on the Pins 'P1SEL, P5SEL'
#define P1SEL_INIT      0x04                    // P1-Modules: P1.2 PWM TA1 options
#define P5SEL_INIT      0                       // P2-Modules:

//Interrupt capabilities of P1 and P2
#define P1IE_INIT       (ROTKEY_A | ROTKEY_BTN) // Interrupt Enable (0=dis 1=enabled)
#define P2IE_INIT       0                       // Interrupt Enable (0=dis 1=enabled)
#define P1IES_INIT      (ROTKEY_A | ROTKEY_BTN) // Interrupt Edge Select (0=rising 1=falling )
#define P2IES_INIT      0                       // Interrupt Edge Select (0=pos 1=neg)

#define IE_INIT         0
#define WDTCTL_INIT     WDTPW|WDTHOLD

#define DCOCTL_INIT     0
#define BCSCTL1_INIT    XT2OFF | DIVA_0 | 7
//customize this if your MSP runs at different speed.
#define DELAY1MS        800U                    // ~1ms @750kHz


// Timers
// Timer A
#define TACTL_INIT      TASSEL_SMCLK | ID_0 | MC_0 | TACLR   // SMCLK/1, Clear TAR, stop

// Timer B              // ACLK/1, Clear TBR, stop, enable interrupts
#define TBCTL_INIT      TBSSEL_ACLK  | ID_3 | MC_0 | TBCLR | TBIE
#define TBCCTL0_INIT    CM_0 | CCIE
#define TB_ONESEC       (32786/8)

// LCD options
#define LCD_EXTRA
#define LCD_4LINETYPE
#endif //HARDWARE_H
